pub enum AttentionAvailabilityError {
CubeCountTooBig(CubeCount),
CubeDimTooBig(CubeDim),
}Expand description
A specific feature required for attention is not available in the current runtime or hardware.
Variants
CubeCountTooBig(CubeCount)
The requested cube count exceeds what the runtime or hardware supports.
CubeDimTooBig(CubeDim)
The requested cube dimensions are too large for the current runtime or hardware.